pub struct MemoryFindService { /* private fields */ }Implementations
Sourceimpl MemoryFindService
impl MemoryFindService
Sourcepub fn new(store: Arc<dyn NodeStore>) -> Self
pub fn new(store: Arc<dyn NodeStore>) -> Self
Create a deterministic memory finder over a shared node store.
Sourcepub async fn execute(
&self,
request: &MemoryFindRequest,
) -> Result<MemoryFindResult>
pub async fn execute( &self, request: &MemoryFindRequest, ) -> Result<MemoryFindResult>
Run predicate-based retrieval with stable sorting and pagination semantics.
This operation does not apply resonance scoring; it filters, sorts, and truncates nodes based only on explicit request criteria.